==> recup_app_storybook-1.5.1.tar.gz: lib/stories/cards/card_story/recup_card_story.dart <==
import 'package:flutter/material.dart';
import 'package:recup_app_storybook/stories/data_display/avatar/avatar.dart';

class RecupCardStory extends StatelessWidget {
  final String backgroundImage;
  final String imageAvatar;
  final String text;
  const RecupCardStory(
      {Key? key,
      required this.backgroundImage,
      required this.imageAvatar,
      required this.text})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Container(
        height: 160,
        width: 128,
        decoration: BoxDecoration(
          image: DecorationImage(
            image: NetworkImage(
              backgroundImage,
            ),
            fit: BoxFit.cover,
            colorFilter: ColorFilter.mode(
              Colors.white.withOpacity(0.6),
              BlendMode.modulate,
            ),
          ),
          borderRadius: const BorderRadius.all(
            Radius.circular(12.0),
          ),
          color: Theme.of(context).colorScheme.background,
        ),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: RecupAvatar(
                foto: imageAvatar,
                colorBorder: Theme.of(context).colorScheme.primary,
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(left: 18, top: 60),
              child: Text(text, style: Theme.of(context).textTheme.labelLarge),
            ),
          ],
        ),
      ),
    );
  }
}

==> recup_app_storybook-1.7.0.tar.gz: lib/stories/cards/card_story/recup_card_story.dart <==
import 'package:flutter/material.dart';
import 'package:recup_app_storybook/stories/data_display/avatar/avatar.dart';

class RecupCardStory extends StatelessWidget {
  final String backgroundImage;
  final String imageAvatar;
  final String text;
  const RecupCardStory({
    Key? key,
    this.backgroundImage = '',
    this.imageAvatar = '',
    this.text = '',
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Container(
        height: 170,
        width: 128,
        decoration: BoxDecoration(
          image: DecorationImage(
            image: NetworkImage(
              backgroundImage,
            ),
            fit: BoxFit.cover,
            colorFilter: ColorFilter.mode(
              Colors.white.withOpacity(0.6),
              BlendMode.modulate,
            ),
          ),
          borderRadius: const BorderRadius.all(
            Radius.circular(12.0),
          ),
          color: Theme.of(context).colorScheme.background,
        ),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: RecupAvatar(
                foto: imageAvatar,
                colorBorder: Theme.of(context).colorScheme.primary,
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(left: 10, top: 60, right: 10),
              child: Text(
                text,
                maxLines: 3,
                overflow: TextOverflow.ellipsis,
                style: Theme.of(context).textTheme.labelLarge,
              ),
            ),
          ],
        ),
      ),
    );
  }
}
